@@ -1,6 +1,9 @@
 
 library(exactRankTests)
-
+actversion <- paste(R.version$major, R.version$minor, sep=".")
+thisversion <- "1.7.0"
+if (compareVersion(actversion, thisversion) >= 0)
+  RNGversion("1.6.2")
 set.seed(29081975)
 
 # test the distribution functions
@@ -101,3 +104,32 @@ for (i in 1:20) {
                       perm.test(r ~ group)$p.value))
 }
 
+
+dansari <- function(x, m ,n)
+{
+    .C("dansari", as.integer(length(x)), d = as.double(x), as.integer(m),
+       as.integer(n), PACKAGE="ctest")$d
+}
+
+# Ansari-Bradley
+
+n <- 10
+x <- rnorm(n, 2, 1)
+y <- rnorm(n, 2, 2)
+
+# exact distribution using Streitberg-Roehmel
+
+sc <- cscores(c(x,y), type="Ansari")
+dabexac <- dperm(0:(n*(2*n+1)/2), sc, n)
+sum(dabexac)
+tr <- which(dabexac > 0)
+
+# exact distribution using dansari (wrapper to ansari.c in ctest)
+
+dab <- dansari(0:(n*(2*n+1)/2), n, n)
+
+# compare the two distributions:
+
+stopifnot(all.equal(max(abs(dab[tr] - dabexac[tr])), 0))
+
+
